@@ -75,7 +75,7 @@ test_listDatabases <- function()
     dbs <- listDatabases()
     for (db in dbs)
     {
-        if (all(db != c("organism", "rpair")))
+        if (all(db != c("organism", "rpair", "environ")))  # environ by vince may 5 2021
         {
             res <- keggInfo(db)
             .checkPlainText(res)
@@ -131,7 +131,7 @@ test_keggGet_2 <- function()
     .checkLOL(res)
     res <- keggGet("path:map00010")
     res <- res[[1]]
-    .checkNamedCharVec(res$DISEASE)
+#    .checkNamedCharVec(res$DISEASE)
     res <- keggGet("md:M00001")
     .checkNamedCharVec(res[[1]]$REACTION)
     .checkNamedCharVec(res[[1]]$ORTHOLOGY)
@@ -142,8 +142,19 @@ test_keggGet_2 <- function()
     x <- res[[1]]$PRODUCT
     checkTrue(all(names(x) == c("PRODUCT","GENERIC")))
     checkTrue(grepl("^ ", res[[1]]$BRITE[2]))
-    res <- keggGet("ev:E00001")
-    .checkCharVec(res[[1]]$CATEGORY)
+#    res <- keggGet("ev:E00001")
+#[1] "http://rest.kegg.jp/get/ev:E00001"
+#Browse[1]> zz = GET(url)
+#Browse[1]> httr::content(zz)
+#NULL
+#Browse[1]> zz
+#Response [http://rest.kegg.jp/get/ev:E00001]
+#  Date: 2021-05-05 12:33
+#  Status: 404
+#  Content-Type: text/plain
+#<EMPTY BODY>
+#
+#    .checkCharVec(res[[1]]$CATEGORY)
     res <- keggGet("ko:K00001")
     checkTrue(names(res[[1]]$ENTRY) == "KO")
     ## DBLINK parser?
@@ -235,3 +246,26 @@ test_reference_parser <- function()
     refs <- res$REFERENCE[[1]]
     checkTrue(length(refs) > 0)
 }
+
+test_keggCompounds <- function() {
+    result <- c(
+        "C00011", "C00042", "C00090", "C00146", "C00160", "C00530",
+        "C00682", "C01407", "C02124", "C02222", "C02375", "C02575", "C02625",
+        "C02814", "C02933", "C03434", "C03572", "C03585", "C03664", "C03918",
+        "C04091", "C04431", "C04522", "C04706", "C04729", "C05618", "C06328",
+        "C06329", "C06594", "C06596", "C06597", "C06598", "C06599", "C06600",
+        "C06601", "C06602", "C06603", "C06755", "C06988", "C06989", "C06990",
+        "C07075", "C07088", "C07089", "C07090", "C07091", "C07092", "C07093",
+        "C07094", "C07095", "C07096", "C07097", "C07098", "C07099", "C07100",
+        "C07101", "C07102", "C07103", "C11352", "C12831", "C12832", "C12833",
+        "C12834", "C12835", "C12836", "C12837", "C12838", "C14419", "C14450",
+        "C16181", "C16182", "C16266", "C18236", "C18238", "C18240", "C18241",
+        "C18242", "C18243", "C18244", "C18933", "C21103", "C21104", "C21105"
+    )
+    checkTrue(
+        all(
+            result %in% keggCompounds("map00361")
+        )
+    )
+}
+
